@@ -2,28 +2,6 @@
 # ConIII module for maxent models.
 # Authors: Edward Lee (edlee@alumni.princeton.edu) and Bryan Daniels
 #          (bryan.daniels.1@asu.edu)
-#
-# MIT License
-# 
-# Copyright (c) 2019 Edward D. Lee, Bryan C. Daniels
-# 
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-# 
-# The above copyright notice and this permission notice shall be included in all
-# copies or substantial portions of the Software.
-# 
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-# SOFTWARE.
 # ====================================================================================== #
 from importlib import import_module
 import multiprocess as mp
@@ -37,7 +15,21 @@ from .samplers import Potts3 as mcPotts3
 class Model():
     """Basic model class outline.
     """
-   
+    def __init__(self, multipliers, rng=None, verbose=False):
+        """
+        Parameters
+        ----------
+        multipliers : list of ndarray or ndarray
+            Can be an integer (all parameters are set to zero), list of vectors [fields,
+            couplings], a vector of fields and couplings concatenated together, or a
+            matrix of parameters where the diagonal entries are the fields.
+        """
+        
+        self.multipliers = multipliers
+        
+        self.rng = rng or np.random.RandomState()  # this will get passed to sampler if it is set up
+        self.verbose = verbose
+  
     def setup_sampler(self,
                       sample_method='metropolis',
                       sample_size=1000,
@@ -66,6 +58,11 @@ class Model():
             self.sampler = mcPotts3(self.n, self.multipliers, self.calc_e,
                                     rng=self.rng,
                                     **sampler_kwargs)
+        elif sample_method=='metropolis':
+            self.sampleMethod = sample_method
+            self.sampler = Metropolis(self.n, self.multipliers, self.calc_e,
+                                      rng=self.rng,
+                                      **sampler_kwargs)
         else:
            raise NotImplementedError("Unrecognized sampler %s."%sample_method)
         self.sample = None
