@@ -5,7 +5,7 @@
 #
 # MIT License
 # 
-# Copyright (c) 2019 Edward D. Lee, Bryan C. Daniels
+# Copyright (c) 2020 Edward D. Lee, Bryan C. Daniels
 # 
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -43,62 +43,62 @@ def test_Metropolis(run_timing=False):
     calc_e, _, _ = define_ising_helper_functions()
     print("Running timing suite for Metropolis sampling functions for n=%d..."%n)
 
-    sampler = Metropolis(n, theta, calc_e, n_cpus=1)
-    print("Running sampler.generate_samples(n)")
-    sampler.generate_samples(100)
+    sampler = Metropolis(n, theta, calc_e)
+    print("Running sampler.generate_sample(n)")
+    sampler.generate_sample(100)
     print("Done.")
 
-    print("Running sampler.generate_samples(n, systematic_iter=True)")
-    sampler.generate_samples(100, systematic_iter=True)
+    print("Running sampler.generate_sample(n, systematic_iter=True)")
+    sampler.generate_sample(100, systematic_iter=True)
     print("Done.")
 
     # test control over rng
-    sampler = Metropolis(n, theta, calc_e, n_cpus=1, rng=np.random.RandomState(0))
-    sampler.generate_samples(100, systematic_iter=True)
-    X1 = sampler.samples.copy()
+    sampler = Metropolis(n, theta, calc_e, rng=np.random.RandomState(0))
+    sampler.generate_sample(100, systematic_iter=True)
+    X1 = sampler.sample.copy()
 
-    sampler = Metropolis(n, theta, calc_e, n_cpus=1, rng=np.random.RandomState(0))
-    sampler.generate_samples(100, systematic_iter=True)
-    X2 = sampler.samples.copy()
+    sampler = Metropolis(n, theta, calc_e, rng=np.random.RandomState(0))
+    sampler.generate_sample(100, systematic_iter=True)
+    X2 = sampler.sample.copy()
 
     assert np.array_equal(X1, X2), (X1, X2)
    
     # parallelization
-    print("Running sampler.generate_samples_parallel(100, systematic_iter=True)")
+    print("Running sampler.generate_sample_parallel(100, systematic_iter=True)")
     sampler = Metropolis(n, theta, calc_e, rng=np.random.RandomState(0))
-    sampler.generate_samples_parallel(100, systematic_iter=True)
-    X1 = sampler.samples.copy()
+    sampler.generate_sample_parallel(100, systematic_iter=True)
+    X1 = sampler.sample.copy()
 
-    print("Running sampler.generate_samples_parallel(100, systematic_iter=True)")
+    print("Running sampler.generate_sample_parallel(100, systematic_iter=True)")
     sampler = Metropolis(n, theta, calc_e, rng=np.random.RandomState(0))
-    sampler.generate_samples_parallel(100, systematic_iter=True)
-    X2 = sampler.samples.copy()
+    sampler.generate_sample_parallel(100, systematic_iter=True)
+    X2 = sampler.sample.copy()
     assert np.array_equal(X1, X2)
 
     # parallelization without systematic iter
-    print("Running sampler.generate_samples_parallel(100, systematic_iter=False)")
+    print("Running sampler.generate_sample_parallel(100, systematic_iter=False)")
     sampler = Metropolis(n, theta, calc_e, rng=np.random.RandomState(0))
-    sampler.generate_samples_parallel(100, systematic_iter=False)
-    X1 = sampler.samples.copy()
+    sampler.generate_sample_parallel(100, systematic_iter=False)
+    X1 = sampler.sample.copy()
 
-    print("Running sampler.generate_samples_parallel(100, systematic_iter=False)")
+    print("Running sampler.generate_sample_parallel(100, systematic_iter=False)")
     sampler = Metropolis(n, theta, calc_e, rng=np.random.RandomState(0))
-    sampler.generate_samples_parallel(100, systematic_iter=False)
-    X2 = sampler.samples.copy()
+    sampler.generate_sample_parallel(100, systematic_iter=False)
+    X2 = sampler.sample.copy()
     assert np.array_equal(X1, X2)
 
     if run_timing:
         # Some basic timing checks
         print("Timing sequential sampling")
-        sampler = Metropolis(n, theta, calc_e, n_cpus=1)
+        sampler = Metropolis(n, theta, calc_e)
         t0=time.perf_counter()
-        sampler.generate_samples(100, n_iters=10000, systematic_iter=True)
+        sampler.generate_sample(100, n_iters=10000, systematic_iter=True)
         print(time.perf_counter()-t0)
         
         print("Timing parallel sampling")
         sampler = Metropolis(n, theta, calc_e)
         t0=time.perf_counter()
-        sampler.generate_samples_parallel(100, n_iters=10000, systematic_iter=True)
+        sampler.generate_sample_parallel(100, n_iters=10000, systematic_iter=True)
         print(time.perf_counter()-t0)
 
 def test_Potts3():
@@ -111,46 +111,46 @@ def test_Potts3():
     print("Running timing suite for Potts3 sampling functions for n=%d..."%n)
 
     sampler = Potts3(n, theta, calc_e, n_cpus=1)
-    print("Running sampler.generate_samples(n)")
-    sampler.generate_samples(100)
+    print("Running sampler.generate_sample(n)")
+    sampler.generate_sample(100)
     print("Done.")
 
-    print("Running sampler.generate_samples(n, systematic_iter=True)")
-    sampler.generate_samples(100, systematic_iter=True)
+    print("Running sampler.generate_sample(n, systematic_iter=True)")
+    sampler.generate_sample(100, systematic_iter=True)
     print("Done.")
 
     # test control over rng
     sampler = Potts3(n, theta, calc_e, n_cpus=1, rng=np.random.RandomState(0))
-    sampler.generate_samples(100, n_iters=10, systematic_iter=True)
-    X1 = sampler.samples.copy()
+    sampler.generate_sample(100, n_iters=10, systematic_iter=True)
+    X1 = sampler.sample.copy()
 
     sampler = Potts3(n, theta, calc_e, n_cpus=1, rng=np.random.RandomState(0))
-    sampler.generate_samples(100, n_iters=10, systematic_iter=True)
-    X2 = sampler.samples.copy()
+    sampler.generate_sample(100, n_iters=10, systematic_iter=True)
+    X2 = sampler.sample.copy()
     assert np.array_equal(X1, X2), (X1[:10], X2[:10])
    
     # parallelization
-    print("Running sampler.generate_samples_parallel(100, systematic_iter=True)")
+    print("Running sampler.generate_sample_parallel(100, systematic_iter=True)")
     sampler = Potts3(n, theta, calc_e, rng=np.random.RandomState(0))
-    sampler.generate_samples_parallel(100, systematic_iter=True)
-    X1 = sampler.samples.copy()
+    sampler.generate_sample_parallel(100, systematic_iter=True)
+    X1 = sampler.sample.copy()
 
-    print("Running sampler.generate_samples_parallel(100, systematic_iter=True)")
+    print("Running sampler.generate_sample_parallel(100, systematic_iter=True)")
     sampler = Potts3(n, theta, calc_e, rng=np.random.RandomState(0))
-    sampler.generate_samples_parallel(100, systematic_iter=True)
-    X2 = sampler.samples.copy()
+    sampler.generate_sample_parallel(100, systematic_iter=True)
+    X2 = sampler.sample.copy()
     assert np.array_equal(X1, X2)
 
     # parallelization without systematic iter
-    print("Running sampler.generate_samples_parallel(100, systematic_iter=False)")
+    print("Running sampler.generate_sample_parallel(100, systematic_iter=False)")
     sampler = Potts3(n, theta, calc_e, rng=np.random.RandomState(0))
-    sampler.generate_samples_parallel(100, systematic_iter=False)
-    X1 = sampler.samples.copy()
+    sampler.generate_sample_parallel(100, systematic_iter=False)
+    X1 = sampler.sample.copy()
 
-    print("Running sampler.generate_samples_parallel(100, systematic_iter=False)")
+    print("Running sampler.generate_sample_parallel(100, systematic_iter=False)")
     sampler = Potts3(n, theta, calc_e, rng=np.random.RandomState(0))
-    sampler.generate_samples_parallel(100, systematic_iter=False)
-    X2 = sampler.samples.copy()
+    sampler.generate_sample_parallel(100, systematic_iter=False)
+    X2 = sampler.sample.copy()
     assert np.array_equal(X1, X2)
 
 def test_ParallelTempering():
@@ -158,7 +158,7 @@ def test_ParallelTempering():
     theta = np.random.normal(size=n+n*(n-1)//2, scale=.1)
     calc_e = define_ising_helper_functions()[0]
     sampler = ParallelTempering(n, theta, calc_e, 4, (1,3))
-    sampler.generate_samples(100)
+    sampler.generate_sample(100)
 
 
 #if __name__=='__main__':
@@ -174,16 +174,16 @@ def compare_samplers():
     
     t0 = time.perf_counter()
     sampler1 = ParallelTempering(n, theta, calc_e, 4, (1,3), replica_burnin=n*100, rep_ex_burnin=n*10)
-    sampler1.generate_samples(nSamples, save_exchange_trajectory=True)
+    sampler1.generate_sample(nSamples, save_exchange_trajectory=True)
     print("Sampler 1 took %1.2f s."%(time.perf_counter()-t0))
     
     t0 = time.perf_counter()
     sampler2 = Metropolis(n, theta, calc_e)
-    sampler2.generate_samples_parallel(nSamples)
+    sampler2.generate_sample_parallel(nSamples)
     print("Sampler 2 took %1.2f s."%(time.perf_counter()-t0))
     
     from .ising_eqn.ising_eqn_5_sym import calc_observables
-    print(sampler1.samples[-1].mean(0), sampler2.samples.mean(0), calc_observables(theta)[:n]) 
-    print(sampler1.samples[-1].std(axis=0)/np.sqrt(nSamples), sampler2.samples.std(axis=0)/np.sqrt(nSamples)) 
+    print(sampler1.sample[-1].mean(0), sampler2.sample.mean(0), calc_observables(theta)[:n]) 
+    print(sampler1.sample[-1].std(axis=0)/np.sqrt(nSamples), sampler2.sample.std(axis=0)/np.sqrt(nSamples)) 
 
     return sampler1, sampler2
